Nidhoggr
========

Yggdrasil protocol implementation

This package provides only API and intended for developers only.

Development
===========

Installation::

    sudo apt-get install libssl-dev swig python3-dev gcc
    python3 -m venv venv
    source venv/bin/activate
    pip install -r requirements_dev.txt -r requirements.txt

To run the all tests run::

    tox
